@@ -13,9 +13,10 @@
 #' 
 #' @param x,y conformable vectors/arrays of type logical or numeric.
 #' @param op a single string, giving the operator. \cr
-#' Supported arithmetic operators: `r paste0(broadcast:::.op_int_math(), collapse = ", ")`. \cr
+#' Supported simple arithmetic operators: `r paste0(broadcast:::.op_int_math(), collapse = ", ")`. \cr
+#' Supported special division arithmetic operators: `r paste0(broadcast:::.op_int_fact(), collapse = ", ")`. \cr
 #' Supported relational operators: `r paste0(broadcast:::.op_int_rel(), collapse = ", ")`. \cr
-#' The "gcd" operator performs the Greatest Common Divisor" operation,
+#' The "gcd" operator performs the "Greatest Common Divisor" operation,
 #' using the Euclidean algorithm.
 #' @param ... further arguments passed to or from methods. \cr \cr
 #' 
@@ -78,10 +79,14 @@ setMethod(
     # get operator:
     op_math <- which(.op_int_math() == op)
     op_rel <- which(.op_int_rel() == op)
+    op_fact <- which(.op_int_fact() == op)
     
     if(length(op_math)) {
       return(.bc_int_math(x, y, op_math, mycall))
     }
+    else if(length(op_fact)) {
+      return(.bc_int_fact(x, y, op_fact, mycall))
+    }
     else if(length(op_rel)) {
       return(.bc_int_rel(x, y, op_rel, mycall))
     }
@@ -102,6 +107,11 @@ setMethod(
     return(numeric(0L))
   }
   
+  if(is.double(x) || is.double(y)) {
+    if(!is.double(x)) x <- as_dbl(x)
+    if(!is.double(y)) y <- as_dbl(y)
+  }
+  
   prep <- .binary_prep(x, y, abortcall)
   x.dim <- prep[[1L]]
   y.dim <- prep[[2L]]
@@ -134,10 +144,6 @@ setMethod(
   
   dim(out) <- out.dimorig
   
-  if(inherits(x, "broadcaster") || inherits(y, "broadcaster")) {
-    .rcpp_set_class(out, "broadcaster")
-  }
-  
   .binary_set_attr(out, x, y)
   
   return(out)
@@ -145,6 +151,58 @@ setMethod(
 }
 
 
+
+#' @keywords internal
+#' @noRd
+.bc_int_fact <- function(x, y, op, abortcall) {
+  
+  if(length(x) == 0L || length(y) == 0L) {
+    return(numeric(0L))
+  }
+  
+  if(is.double(x) || is.double(y)) {
+    if(!is.double(x)) x <- as_dbl(x)
+    if(!is.double(y)) y <- as_dbl(y)
+  }
+  
+  prep <- .binary_prep(x, y, abortcall)
+  x.dim <- prep[[1L]]
+  y.dim <- prep[[2L]]
+  # x.len <- prep[[3L]]
+  # y.len <- prep[[4L]]
+  out.dimorig <- prep[[3L]]
+  out.dimsimp <- prep[[4L]]
+  out.len <- prep[[5L]]
+  dimmode <- prep[[6L]]
+  
+  if(dimmode == 1L) { # vector mode
+    out <- .rcpp_bcFact_int_v(x, y, out.len, op)
+  }
+  else if(dimmode == 2L) { # orthogonal vector mode
+    RxC <- x.dim[1L] != 1L # check if `x` is a column-vector (and thus y is a row-vector)
+    out <- .rcpp_bcFact_int_ov(x, y, RxC, out.dimsimp, out.len, op)
+  }
+  else if(dimmode == 3L) { # general mode
+    
+    by_x <- .C_make_by(x.dim)
+    by_y <- .C_make_by(y.dim)
+    dcp_x <- .C_make_dcp(x.dim)
+    dcp_y <- .C_make_dcp(y.dim)
+    
+    out <- .rcpp_bcFact_int_d(
+      x, y, by_x, by_y,
+      dcp_x, dcp_y, as.integer(out.dimsimp), out.len, op
+    )
+  }
+  
+  dim(out) <- out.dimorig
+  
+  .binary_set_attr(out, x, y)
+  
+  return(out)
+  
+}
+
 #' @keywords internal
 #' @noRd
 .bc_int_rel <- function(x, y, op, abortcall) {
@@ -153,6 +211,11 @@ setMethod(
     return(logical(0L))
   }
   
+  if(is.double(x) || is.double(y)) {
+    if(!is.double(x)) x <- as_dbl(x)
+    if(!is.double(y)) y <- as_dbl(y)
+  }
+  
   prep <- .binary_prep(x, y, abortcall)
   x.dim <- prep[[1L]]
   y.dim <- prep[[2L]]
@@ -184,10 +247,6 @@ setMethod(
   
   dim(out) <- out.dimorig
   
-  if(inherits(x, "broadcaster") || inherits(y, "broadcaster")) {
-    .rcpp_set_class(out, "broadcaster")
-  }
-  
   .binary_set_attr(out, x, y)
   
   return(out)
