@@ -31,20 +31,22 @@ setMethod(
   "bc.rel", c(x = "ANY", y = "ANY"),
   function(x, y, op) {
     
+    mycall <- "bc.rel"
+    
     # checks:
-    .binary_stop_general(x, y, op, sys.call())
+    .binary_stop_general(x, y, op, mycall)
     if(!is.atomic(x) || !is.atomic(y)) {
-      stop("only atomic arrays supported for general relational operators")
+      stop(simpleError("only atomic arrays supported for general relational operators", call = mycall))
     }
     
     # get operator:
     op <- which(.op_rel() == op)
     
     if(length(op)) {
-      return(.bc.rel(x, y, op, sys.call()))
+      return(.bc.rel(x, y, op, mycall))
     }
     else {
-      stop("given operator not supported in the given context")
+      stop(simpleError("given operator not supported in the given context", call = mycall))
     }
   }
 )
@@ -54,10 +56,10 @@ setMethod(
 #' @noRd
 .bc.rel <- function(x, y, op, abortcall) {
   if(op %in% c(1L, 2L)) {
-    .overload_relop_equneq(x, y, op, sys.call())
+    .overload_relop_equneq(x, y, op, abortcall)
   }
   else {
-    .overload_relop_gs(x, y, op, sys.call())
+    .overload_relop_gs(x, y, op, abortcall)
   }
 }
 
