@@ -13,10 +13,9 @@ using namespace Rcpp;
 // [[Rcpp::export(.rcpp_bcRel_dec_v)]]
 SEXP rcpp_bcRel_dec_v(
   SEXP x, SEXP y,
-  R_xlen_t nout, int op, double prec
+  R_xlen_t nout, int op
 ) {
 
-double tempcalc;
 int tempout;
 
 SEXP out = PROTECT(Rf_allocVector(LGLSXP, nout));
@@ -39,10 +38,9 @@ return out;
 // [[Rcpp::export(.rcpp_bcRel_dec_ov)]]
 SEXP rcpp_bcRel_dec_ov(
   SEXP x, SEXP y, bool RxC, SEXP out_dim,
-  R_xlen_t nout, int op, double prec
+  R_xlen_t nout, int op
 ) {
 
-double tempcalc;
 int tempout;
 
 SEXP out = PROTECT(Rf_allocVector(LGLSXP, nout));
@@ -66,11 +64,10 @@ SEXP rcpp_bcRel_dec_d(
   SEXP x, SEXP y,
   SEXP by_x,
   SEXP by_y,
-  SEXP dcp_x, SEXP dcp_y, SEXP out_dim, R_xlen_t nout, int op, double prec
+  SEXP dcp_x, SEXP dcp_y, SEXP out_dim, R_xlen_t nout, int op
 ) {
 
 
-double tempcalc;
 int tempout;
 
 SEXP out = PROTECT(Rf_allocVector(LGLSXP, nout));
