@@ -21,11 +21,6 @@ inline bool rcpp_isFALSE(
   return(x != NA_INTEGER && x == 0);
 }
 
-inline bool rcpp_is_lgl(
-  SEXP x
-) {
-  return(TYPEOF(x) == INTSXP || TYPEOF(x) == LGLSXP);
-}
 
 
 //' @keywords internal
@@ -46,15 +41,17 @@ if(TYPEOF(x) == RAWSXP && TYPEOF(y) == RAWSXP) {
    SEXP out = PROTECT(Rf_allocVector(RAWSXP, nout));
    Rbyte *pout;
    pout = RAW(out);
-   MACRO_OP_B_RAW(MACRO_DIM_VECTOR);
+   MACRO_OP_BOOL_ANDOR_RAW(MACRO_DIM_VECTOR);
    UNPROTECT(1);
    return out;
 }
 else {
+   const int *px = INTEGER_RO(x);
+   const int *py = INTEGER_RO(y);
    SEXP out = PROTECT(Rf_allocVector(LGLSXP, nout));
    int *pout;
    pout = LOGICAL(out); 
-   MACRO_TYPESWITCH_BOOL(MACRO_DIM_VECTOR);
+   MACRO_OP_BOOL_ANDOR_INT(MACRO_DIM_VECTOR);
    UNPROTECT(1);
    return out;
 }
@@ -80,16 +77,18 @@ if(TYPEOF(x) == RAWSXP && TYPEOF(y) == RAWSXP) {
    SEXP out = PROTECT(Rf_allocVector(RAWSXP, nout));
    Rbyte *pout;
    pout = RAW(out);
-   MACRO_OP_B_RAW(MACRO_DIM_ORTHOVECTOR);
+   MACRO_OP_BOOL_ANDOR_RAW(MACRO_DIM_ORTHOVECTOR);
    UNPROTECT(1);
    return out;
 
 }
 else {
+   const int *px = INTEGER_RO(x);
+   const int *py = INTEGER_RO(y);
    SEXP out = PROTECT(Rf_allocVector(LGLSXP, nout));
    int *pout;
    pout = LOGICAL(out); 
-   MACRO_TYPESWITCH_BOOL(MACRO_DIM_ORTHOVECTOR);
+   MACRO_OP_BOOL_ANDOR_INT(MACRO_DIM_ORTHOVECTOR);
    UNPROTECT(1);
    return out;
 }
@@ -117,15 +116,17 @@ if(TYPEOF(x) == RAWSXP && TYPEOF(y) == RAWSXP) {
    SEXP out = PROTECT(Rf_allocVector(RAWSXP, nout));
    Rbyte *pout;
    pout = RAW(out);
-   MACRO_OP_B_RAW(MACRO_DIM_DOCALL);
+   MACRO_OP_BOOL_ANDOR_RAW(MACRO_DIM_DOCALL);
    UNPROTECT(1);
    return out;
 }
 else {
+   const int *px = INTEGER_RO(x);
+   const int *py = INTEGER_RO(y);
    SEXP out = PROTECT(Rf_allocVector(LGLSXP, nout));
    int *pout;
    pout = LOGICAL(out); 
-   MACRO_TYPESWITCH_BOOL(MACRO_DIM_DOCALL);
+   MACRO_OP_BOOL_ANDOR_INT(MACRO_DIM_DOCALL);
    UNPROTECT(1);
    return out;
 }
